@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_grdio.c,v 1.76 2006/05/21 04:37:14 pwessel Exp $
+ *	$Id: gmt_grdio.c,v 1.84 2006/10/30 21:18:19 remko Exp $
  *
  *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
@@ -62,6 +62,12 @@ int GMT_grdformats[GMT_N_GRD_FORMATS][2] = {
 void GMT_grd_do_scaling (float *grid, int nm, double scale, double offset);
 void GMT_grd_get_units (struct GRD_HEADER *header);
 void GMT_grd_set_units (struct GRD_HEADER *header);
+int GMT_is_nc_grid (char *file);
+int GMT_is_native_grid (char *file);
+int GMT_is_ras_grid (char *file);
+int GMT_is_srf_grid (char *file);
+int GMT_is_mgg2_grid (char *file);
+int GMT_is_agc_grid (char *file);
 
 /* GENERIC I/O FUNCTIONS FOR GRIDDED DATA FILES */
 
@@ -77,7 +83,7 @@ int GMT_read_grd_info (char *file, struct GRD_HEADER *header)
 	GMT_grd_init (header, 0, (char **)VNULL, FALSE);
 
 	/* Save parameters on file name suffix before issuing GMT_io_readinfo */
-	header->type = GMT_grd_get_format (file, header);
+	GMT_grd_get_format (file, header, TRUE);
 	scale = header->z_scale_factor, offset = header->z_add_offset, nan_value = header->nan_value;
 
 	status = (*GMT_io_readinfo[header->type]) (header);
@@ -100,8 +106,8 @@ int GMT_write_grd_info (char *file, struct GRD_HEADER *header)
 	 */
 
 	int status;
-	
-	header->type = GMT_grd_get_format (file, header);
+
+	GMT_grd_get_format (file, header, FALSE);
 	if (GMT_is_dnan(header->z_scale_factor))
 		header->z_scale_factor = 1.0;
 	else if (header->z_scale_factor == 0.0) {
@@ -121,9 +127,10 @@ int GMT_update_grd_info (char *file, struct GRD_HEADER *header)
 	 */
 
 	int status;
-	
+
 	header->z_min = (header->z_min - header->z_add_offset) / header->z_scale_factor;
 	header->z_max = (header->z_max - header->z_add_offset) / header->z_scale_factor;
+	GMT_grd_set_units (header);
 	status = (*GMT_io_updateinfo[header->type]) (header);
 	return (status);
 }
@@ -163,7 +170,7 @@ int GMT_write_grd (char *file, struct GRD_HEADER *header, float *grid, double w,
 
 	int status;
 
-	header->type = GMT_grd_get_format (file, header);
+	GMT_grd_get_format (file, header, FALSE);
 	if (GMT_is_dnan(header->z_scale_factor))
 		header->z_scale_factor = 1.0;
 	else if (header->z_scale_factor == 0.0) {
@@ -200,9 +207,9 @@ void GMT_expand_filename (char *file, char *fname)
 		strcpy (fname, file);
 }
 
-int GMT_grd_get_format (char *file, struct GRD_HEADER *header)
+void GMT_grd_get_format (char *file, struct GRD_HEADER *header, BOOLEAN magic)
 {
-	int i = 0, j, id = 0;
+	int i = 0, j;
 	char code[GMT_TEXT_LEN];
 
 	GMT_expand_filename (file, header->name);
@@ -215,16 +222,32 @@ int GMT_grd_get_format (char *file, struct GRD_HEADER *header)
 	if (header->name[i]) {	/* Get format type, scale, offset and missing value from suffix */
 		i++;
 		sscanf (&header->name[i], "%[^/]/%lf/%lf/%lf", code, &header->z_scale_factor, &header->z_add_offset, &header->nan_value);
-		id = GMT_grd_format_decoder (code);
+		header->type = GMT_grd_format_decoder (code);
 		j = (i == 1) ? i : i - 1;
 		header->name[j] = 0;
 	}
+	else if (magic) {	/* Determine file format automatically based on grid content */
+
+		/* First check if we have a netCDF grid */
+		if ((header->type = GMT_is_nc_grid (header->name)) >= 0) return;
+		/* Then check for native GMT grid */
+		if ((header->type = GMT_is_native_grid (header->name)) >= 0) return;
+		/* Next check for Sun raster GMT grid */
+		if ((header->type = GMT_is_ras_grid (header->name)) >= 0) return;
+		/* Then check for Golden Software surfer grid */
+		if ((header->type = GMT_is_srf_grid (header->name)) >= 0) return;
+		/* Then check for NGDC GRD98 GMT grid */
+		if ((header->type = GMT_is_mgg2_grid (header->name)) >= 0) return;
+		/* Then check for AGC GMT grid */
+		if ((header->type = GMT_is_agc_grid (header->name)) >= 0) return;
+
+		fprintf (stderr, "Could not determine grid type of file %s\n", header->name);
+		exit (EXIT_FAILURE);
+	}
 	else {			/* Get format type, scale, offset and missing value from gmtdefs.grid_format */
 		sscanf (gmtdefs.grid_format, "%[^/]/%lf/%lf/%lf", code, &header->z_scale_factor, &header->z_add_offset, &header->nan_value);
-		id = GMT_grd_format_decoder (code);
+		header->type = GMT_grd_format_decoder (code);
 	}
-
-	return (id);
 }
 
 int GMT_grd_data_size (int format, double *nan_value)
@@ -262,7 +285,7 @@ int GMT_grd_format_decoder (const char *code)
 	/* Returns the integer grid format ID that goes with the specified 2-character code */
 
 	int id;
-	
+
 	if (isdigit ((int)code[0])) {	/* File format number given, convert directly */
 		id = atoi (code);
  		if (id < 0 || id >= GMT_N_GRD_FORMATS) {
@@ -278,7 +301,7 @@ int GMT_grd_format_decoder (const char *code)
 				if (GMT_grdformats[i][1] == (short)code[1]) id = i;
 			}
 		}
-		
+
 		if (id == -1) {
 			if (group) fprintf (stderr, "%s: GMT ERROR: grdfile format type (%c) for group %c is unknown!\n", GMT_program, code[1], code[0]);
 			else fprintf (stderr, "%s: GMT ERROR: grdfile format code %s unknown!\n", GMT_program, code);
@@ -287,7 +310,7 @@ int GMT_grd_format_decoder (const char *code)
 	}
 
 	return (id);
-}	
+}
 
 void GMT_grd_do_scaling (float *grid, int nm, double scale, double offset)
 {
@@ -295,7 +318,7 @@ void GMT_grd_do_scaling (float *grid, int nm, double scale, double offset)
 	int i;
 
 	if (scale == 1.0 && offset == 0.0) return;
-	
+
 	if (scale == 1.0)
 		for (i = 0; i < nm; i++) grid[i] += (float)offset;
 	else if (offset == 0.0)
@@ -313,9 +336,9 @@ void GMT_grd_do_scaling (float *grid, int nm, double scale, double offset)
 void GMT_grd_RI_verify (struct GRD_HEADER *h, int mode)
 {
 	/* mode - 0 means we are checking an existing grid, mode = 1 means we test a new -R -I combination */
-	
+
 	int error = 0;
-	
+
 	if (!strcmp (GMT_program, "grdedit")) return;	/* Separate handling in grdedit to allow grdedit -A */
 
 	switch (GMT_minmaxinc_verify (h->x_min, h->x_max, h->x_inc, GMT_SMALL)) {
@@ -334,7 +357,7 @@ void GMT_grd_RI_verify (struct GRD_HEADER *h, int mode)
 			/* Everything is OK */
 			break;
 	}
-		
+
 	switch (GMT_minmaxinc_verify (h->y_min, h->y_max, h->y_inc, GMT_SMALL)) {
 		case 3:
 			(void) fprintf (stderr, "%s: GMT ERROR: grid y increment <= 0.0\n", GMT_program);
@@ -373,7 +396,7 @@ int *GMT_grd_prep_io (struct GRD_HEADER *header, double *w, double *e, double *s
 
 	if (*w == 0.0 && *e == 0.0) {	/* Get entire file */
 		*width  = header->nx;
-		*height = header->ny;	
+		*height = header->ny;
 		*first_col = *first_row = 0;
 		*last_col  = header->nx - 1;
 		*last_row  = header->ny - 1;
@@ -394,14 +417,14 @@ int *GMT_grd_prep_io (struct GRD_HEADER *header, double *w, double *e, double *s
 		/* Make sure w,e,s,n are proper multiples of dx,dy away from w, s */
 
 		GMT_adjust_loose_wesn (w, e, s, n, header);
-		
+
 		/* Get dimension of subregion */
-	
+
 		*width  = irint ((*e - *w) / header->x_inc) + one_or_zero;
 		*height = irint ((*n - *s) / header->y_inc) + one_or_zero;
-	
+
 		/* Get first and last row and column numbers */
-	
+
 		small = 0.1 * header->x_inc;
 		*first_col = (int)floor ((*w - header->x_min + small) / header->x_inc);
 		*last_col  = (int)ceil  ((*e - header->x_min - small) / header->x_inc) - 1 + one_or_zero;
@@ -443,7 +466,7 @@ void GMT_decode_grd_h_info (char *input, struct GRD_HEADER *h) {
 */
 	char	ptr[BUFSIZ];
 	int	entry = 0, pos = 0;
-	
+
 	while ((GMT_strtok (input, "/", &pos, ptr))) {
 		if (ptr[0] != '=') {
 			switch (entry) {
@@ -493,24 +516,24 @@ void GMT_open_grd (char *file, struct GMT_GRDFILE *G, char mode)
 	 * mode can be w or r.  Upper case W or R refers to headerless
 	 * grdraster-type files.
 	 */
-	
+
 	int r_w;
 	int cdf_mode[3] = { NC_NOWRITE, NC_WRITE, NC_WRITE};
 	char *bin_mode[3] = { "rb", "rb+", "wb"};
-	BOOLEAN header = TRUE;
+	BOOLEAN header = TRUE, magic = TRUE;
 	EXTERN_MSC int GMT_nc_grd_info (struct GRD_HEADER *header, char job);
-	 
+
 	if (mode == 'r' || mode == 'R') {	/* Open file for reading */
 		if (mode == 'R') header = FALSE;
 		r_w = 0;
 	}
 	else if (mode == 'W') {
 		r_w = 2;
-		header = FALSE;
+		header = magic = FALSE;
 	}
 	else
 		r_w = 1;
- 	G->header.type = GMT_grd_get_format (file, &G->header);
+ 	GMT_grd_get_format (file, &G->header, magic);
 	if (GMT_is_dnan(G->header.z_scale_factor))
 		G->header.z_scale_factor = 1.0;
 	else if (G->header.z_scale_factor == 0.0) {
@@ -549,9 +572,9 @@ void GMT_open_grd (char *file, struct GMT_GRDFILE *G, char mode)
 		G->n_byte = irint (ceil (G->header.nx / 2.0)) * 2 * G->size;
 	else	/* All other */
 		G->n_byte = G->header.nx * G->size;
-			
+
 	G->v_row = (void *) GMT_memory (VNULL, G->n_byte, 1, GMT_program);
-	
+
 	G->row = 0;
 	G->auto_advance = TRUE;	/* Default is to read sequential rows */
 }
@@ -569,7 +592,7 @@ void GMT_read_grd_row (struct GMT_GRDFILE *G, int row_no, float *row)
 	 * If row_no is negative it is interpreted to mean that we want to
 	 * fseek to the start of the abs(row_no) record and no reading takes place.
 	 */
-	 
+
 	int i;
 
 	if (GMT_grdformats[G->header.type][0] == 'c') {		/* Get one NetCDF row, old format */
@@ -613,17 +636,17 @@ void GMT_read_grd_row (struct GMT_GRDFILE *G, int row_no, float *row)
 
 void GMT_write_grd_row (struct GMT_GRDFILE *G, int row_no, float *row)
 {	/* Writes the entire row vector to the grdfile */
-	
+
 	int i, size;
 	void *tmp;
 
 	size = GMT_grd_data_size (G->header.type, &G->header.nan_value);
-	
+
 	tmp = (void *) GMT_memory (VNULL, (size_t)G->header.nx, size, "GMT_write_grd_row");
 
 	GMT_grd_do_scaling (row, G->header.nx, G->scale, G->offset);
 	for (i = 0; i < G->header.nx; i++) if (GMT_is_fnan (row[i]) && G->check) row[i] = (float)G->header.nan_value;
-	
+
 	switch (GMT_grdformats[G->header.type][0]) {
 		case 'c':
 			check_nc_status (nc_put_vara_float (G->fid, G->header.z_id, G->start, G->edge, row));
@@ -645,7 +668,7 @@ void GMT_write_grd_row (struct GMT_GRDFILE *G, int row_no, float *row)
  * GMT_grd_init initializes a grd header to default values and copies the
  * command line to the header variable command
  */
- 
+
 void GMT_grd_init (struct GRD_HEADER *header, int argc, char **argv, BOOLEAN update)
 {	/* TRUE if we only want to update command line */
 	int i, len;
@@ -682,7 +705,7 @@ void GMT_grd_init (struct GRD_HEADER *header, int argc, char **argv, BOOLEAN upd
 	header->z_id			= -1;
 	header->nan_value		= GMT_d_NaN;
 	header->xy_off			= 0.0;
-	
+
 	memset ((void *)header->name, 0, (size_t)GMT_LONG_TEXT);
 
 	memset ((void *)header->x_units, 0, (size_t)GRD_UNIT_LEN);
@@ -696,10 +719,8 @@ void GMT_grd_init (struct GRD_HEADER *header, int argc, char **argv, BOOLEAN upd
 }
 
 void GMT_grd_shift (struct GRD_HEADER *header, float *grd, double shift)
-                          
-            
-             		/* Rotate geographical, global grid in e-w direction */
 {
+	/* Rotate geographical, global grid in e-w direction */
 	/* This function will shift a grid by shift degrees */
 
 	int i, j, k, ij, nc, nx1, n_shift, width, n_warn = 0;
@@ -777,7 +798,7 @@ int GMT_grd_setregion (struct GRD_HEADER *h, double *xmin, double *xmax, double
 			*ymax = h->y_max;
 			if ((*ymin) < h->y_min) *ymin = h->y_min;
 		}
-		else {			/* South pole included, need all longitudes but restrict latitudes */	
+		else {			/* South pole included, need all longitudes but restrict latitudes */
 			*xmin = h->x_min;	*xmax = h->x_max;
 			*ymin = h->y_min;
 			*ymax = GMT_j_to_y (GMT_y_to_j (project_info.n, h->y_min, h->y_inc, 0.0, h->ny), h->y_min, h->y_max, h->y_inc, 0.0, h->ny);
@@ -785,7 +806,7 @@ int GMT_grd_setregion (struct GRD_HEADER *h, double *xmin, double *xmax, double
 		}
 		return (0);
 	}
-	
+
 	/* Weakness in the logic below is that there is no flag in the grid to tell us it is lon/lat data.
 	 * We infer the grid is global (in longitude) and geographic if w-e == 360 && |s,n| <= 90 */
 
@@ -852,7 +873,7 @@ int GMT_grd_setregion (struct GRD_HEADER *h, double *xmin, double *xmax, double
 		 * Must make sure the grid w/e is in same range when comparing.
 		 */
 		 shift_x = (h->x_max < project_info.w) ? 360.0 : 0.0;	/* Shift to SUBTRACT from w/e ... when comparing */
-	}		 
+	}
 	else {	/* Case 3b: Grid straddles Greenwich but region doesnt */
 		/* Here we KNOW that w/e has been forced to be positive (0-360 range).
 		 * Make sure the grid w/e is in same range
@@ -879,7 +900,7 @@ int GMT_grd_setregion (struct GRD_HEADER *h, double *xmin, double *xmax, double
 }
 
 void GMT_grd_set_units (struct GRD_HEADER *header)
-{	
+{
 	/* Set unit strings for grid coordinates x, y and z based on
 	   output data types for columns 0, 1, and 2.
 	*/
@@ -891,7 +912,21 @@ void GMT_grd_set_units (struct GRD_HEADER *header)
 	string[1] = header->y_units;
 	string[2] = header->z_units;
 
-	/* Set unit strings one by one */
+	/* Use input data type as backup fr output data type */
+	for (i = 0; i < 3; i++) 
+		if (GMT_io.out_col_type[i] == GMT_IS_UNKNOWN) GMT_io.out_col_type[i] = GMT_io.in_col_type[i];
+
+	/* Catch some anomalies */
+	if (GMT_io.out_col_type[0] == GMT_IS_LAT) {
+		fprintf (stderr, "%s: Output type for X-coordinate of grid %s is LAT. Replaced by LON.\n", GMT_program, header->name);
+		GMT_io.out_col_type[0] = GMT_IS_LON;
+	}
+	if (GMT_io.out_col_type[1] == GMT_IS_LON) {
+		fprintf (stderr, "%s: Output type for Y-coordinate of grid %s is LON. Replaced by LAT.\n", GMT_program, header->name);
+		GMT_io.out_col_type[1] = GMT_IS_LAT;
+	}
+
+	/* Set unit strings one by one based on output type */
 	for (i = 0; i < 3; i++) {
 		switch (GMT_io.out_col_type[i]) {
 		case GMT_IS_LON:
@@ -926,14 +961,14 @@ void GMT_grd_set_units (struct GRD_HEADER *header)
 }
 
 void GMT_grd_get_units (struct GRD_HEADER *header)
-{	
+{
 	/* Set input data types for columns 0, 1 and 2 based on unit strings for
 	   grid coordinates x, y and z.
 	   When "Time": transform the data scale and offset to match the current time system.
 	*/
 	int i;
 	char *string[3], cal[GRD_UNIT_LEN], *l;
-	double scale, offset;
+	double scale = 1.0, offset = 0.0;
 
 	/* Copy pointers to unit strings */
 	string[0] = header->x_units;
@@ -943,19 +978,32 @@ void GMT_grd_get_units (struct GRD_HEADER *header)
 	/* Parse the unit strings one by one */
 	for (i = 0; i < 3; i++) {
 		/* Skip parsing when input data type is already set */
-		if (GMT_io.in_col_type[i] & GMT_IS_GEO || GMT_io.in_col_type[i] & GMT_IS_RATIME) continue;
+		if (GMT_io.in_col_type[i] & GMT_IS_GEO) {
+			project_info.degree[i] = TRUE;
+			continue;
+		}
+		else if (GMT_io.in_col_type[i] & GMT_IS_RATIME) {
+			project_info.xyz_projection[i] = GMT_TIME;
+			continue;
+		}
 
-		if (strstr (string[i], "degrees_e") || !strncmp (string[i], "Lon", 3) || !strncmp (string[i], "lon", 3))
+		/* Change name of variable and unit to lower case for comparison */
+		GMT_str_tolower (string[i]);
+
+		if (!strncmp (string[i], "lon", 3) || strstr (string[i], "degrees_e")) {
 			/* Input data type is longitude */
 			GMT_io.in_col_type[i] = GMT_IS_LON;
-
-		else if (strstr (string[i], "degrees_n") || !strncmp (string[i], "Lat", 3) || !strncmp (string[i], "lat", 3))
+			project_info.degree[i] = TRUE;
+		}
+		else if (!strncmp (string[i], "lat", 3) || strstr (string[i], "degrees_n")) {
 			/* Input data type is latitude */
 			GMT_io.in_col_type[i] = GMT_IS_LAT;
-
+			project_info.degree[i] = TRUE;
+		}
 		else if (!strncmp (string[i], "time", 4)) {
 			/* Input data type is time */
 			GMT_io.in_col_type[i] = GMT_IS_RELTIME;
+			project_info.xyz_projection[i] = GMT_TIME;
 			/* Determine relative time units */
 			if (strstr (string[i], "years"))
 				scale = GMT_YR2SEC_F / GMT_time_system[gmtdefs.time_system].scale;
@@ -971,9 +1019,7 @@ void GMT_grd_get_units (struct GRD_HEADER *header)
 				scale = 1.0 / GMT_time_system[gmtdefs.time_system].scale;
 			else
 				fprintf (stderr, "%s: Warning: Time unit in grid not recognised; assumed %c.\n", GMT_program, GMT_time_system[gmtdefs.time_system].unit);
-				scale = 1.0;
 			/* Determine relative time epoch */
-			offset = 0.0;
 			if ((l = strstr (string[i], "since"))) {
 				l += 6;
 				strcpy (cal, l);
@@ -1021,18 +1067,14 @@ void GMT_read_img (char *imgfile, struct GRD_HEADER *grd, float **grid, double w
 	 * GMT grid.  If init is TRUE we also initialize the Mercator projection.  Lat should be 0.0
 	 * if we are dealing with standard 72 or 80 img latitude; else it must be specified.
 	 */
-	 
+
 	int min, i, j, k, ij, mx, my, first_i, n_skip, n_cols;
 	short int *i2;
 	char file[BUFSIZ];
 	struct STAT buf;
 	FILE *fp;
-	
-	if (!access (imgfile, R_OK))	/* File is in local directory */
-		strcpy (file, imgfile);
-	else if (GMT_IMGDIR)	/* Try GMT_IMGDIR */
-		sprintf (file, "%s%c%s", GMT_IMGDIR, DIR_DELIM, imgfile);
-	else {
+
+	if (!GMT_getdatapath (imgfile, file)) {
 		fprintf (stderr, "%s: Unable to find file %s\n", GMT_program, imgfile);
 		exit (EXIT_FAILURE);
 	}
@@ -1040,22 +1082,22 @@ void GMT_read_img (char *imgfile, struct GRD_HEADER *grd, float **grid, double w
 		fprintf (stderr, "%s: Unable to stat file %s\n", GMT_program, imgfile);
 		exit (EXIT_FAILURE);
 	}
-	
+
 	switch (buf.st_size) {	/* Known sizes are 1 or 2 min at lat_max = 72 or 80 */
 		case GMT_IMG_NLON_1M*GMT_IMG_NLAT_1M_80*GMT_IMG_ITEMSIZE:
-			if (lat == 0.0) lat = GMT_IMG_MAXLAT_80;	
+			if (lat == 0.0) lat = GMT_IMG_MAXLAT_80;
 		case GMT_IMG_NLON_1M*GMT_IMG_NLAT_1M_72*GMT_IMG_ITEMSIZE:
-			if (lat == 0.0) lat = GMT_IMG_MAXLAT_72;	
+			if (lat == 0.0) lat = GMT_IMG_MAXLAT_72;
 			min = 1;
 			break;
 		case GMT_IMG_NLON_2M*GMT_IMG_NLAT_2M_80*GMT_IMG_ITEMSIZE:
-			if (lat == 0.0) lat = GMT_IMG_MAXLAT_80;	
+			if (lat == 0.0) lat = GMT_IMG_MAXLAT_80;
 		case GMT_IMG_NLON_2M*GMT_IMG_NLAT_2M_72*GMT_IMG_ITEMSIZE:
-			if (lat == 0.0) lat = GMT_IMG_MAXLAT_72;	
+			if (lat == 0.0) lat = GMT_IMG_MAXLAT_72;
 			min = 2;
 			break;
 		default:
-			if (lat == 0.0) {	
+			if (lat == 0.0) {
 				fprintf (stderr, "%s: Must specify max latitude for img file %s\n", GMT_program, file);
 				exit (EXIT_FAILURE);
 			}
@@ -1068,10 +1110,10 @@ void GMT_read_img (char *imgfile, struct GRD_HEADER *grd, float **grid, double w
 		w = GMT_IMG_MINLON;	e = GMT_IMG_MAXLON;
 		s = -lat;	n = lat;
 	}
-	
+
 	GMT_grd_init (grd, 0, NULL, FALSE);
 	grd->x_inc = grd->y_inc = min / 60.0;
-	
+
 	if ((fp = GMT_fopen (file, "rb")) == NULL) {
 		fprintf (stderr, "%s: Error opening img file %s\n", GMT_program, file);
 		exit (EXIT_FAILURE);
@@ -1084,29 +1126,29 @@ void GMT_read_img (char *imgfile, struct GRD_HEADER *grd, float **grid, double w
 		project_info.pars[0] = 1.0;
 		project_info.projection = GMT_MERCATOR;
 		project_info.degree[0] = project_info.degree[1] = TRUE;
-	
+
 		GMT_map_setup (GMT_IMG_MINLON, GMT_IMG_MAXLON, -lat, +lat);
 	}
-	
+
 	if (w < 0.0 && e < 0.0) w += 360.0, e += 360.0;
-	
+
 	GMT_geo_to_xy (w, s, &grd->x_min, &grd->y_min);
 	GMT_geo_to_xy (e, n, &grd->x_max, &grd->y_max);
-	
+
 	grd->x_min = MAX (GMT_IMG_MINLON, floor (grd->x_min / grd->x_inc) * grd->x_inc);
 	grd->x_max = MIN (GMT_IMG_MAXLON, ceil (grd->x_max / grd->x_inc) * grd->x_inc);
 	if (grd->x_min > grd->x_max) grd->x_min -= 360.0;
 	grd->y_min = MAX (0.0, floor (grd->y_min / grd->y_inc) * grd->y_inc);
 	grd->y_max = MIN (project_info.ymax, ceil (grd->y_max / grd->y_inc) * grd->y_inc);
 	/* Allocate grid memory */
-	
+
 	grd->node_offset = 1;	/* These are always pixel grids */
 	grd->nx = GMT_get_n (grd->x_min, grd->x_max, grd->x_inc, grd->node_offset);
 	grd->ny = GMT_get_n (grd->y_min, grd->y_max, grd->y_inc, grd->node_offset);
 	mx = grd->nx + GMT_pad[0] + GMT_pad[2];	my = grd->ny + GMT_pad[1] + GMT_pad[3];
 	*grid = (float *) GMT_memory (VNULL, (size_t)(mx * my), sizeof (float), GMT_program);
 	grd->xy_off = 0.5;
-	
+
 	n_cols = (min == 1) ? GMT_IMG_NLON_1M : GMT_IMG_NLON_2M;		/* Number of columns (10800 or 21600) */
 	first_i = (int)floor (grd->x_min / grd->x_inc);				/* first tile partly or fully inside region */
 	if (first_i < 0) first_i += n_cols;
@@ -1115,7 +1157,7 @@ void GMT_read_img (char *imgfile, struct GRD_HEADER *grd, float **grid, double w
 		fprintf (stderr, "%s: Unable to seek ahead in file %s\n", GMT_program, imgfile);
 		exit (EXIT_FAILURE);
 	}
-	
+
 	i2 = (short int *) GMT_memory (VNULL, (size_t)n_cols, sizeof (short int), GMT_program);
 	for (j = 0; j < grd->ny; j++) {	/* Read all the rows, offset by 2 boundary rows and cols */
 		ij = (j + GMT_pad[3]) * mx + GMT_pad[0];
@@ -1146,10 +1188,10 @@ void GMT_read_img (char *imgfile, struct GRD_HEADER *grd, float **grid, double w
 struct GMT_GRID *GMT_create_grid (char *arg)
 {	/* Allocates space for a new grid container.  No space allocated for the float grid itself */
 	struct GMT_GRID * G;
-	
+
 	G = (struct GMT_GRID *) GMT_memory (VNULL, 1, sizeof (struct GMT_GRID), arg);
 	G->header = (struct GRD_HEADER *) GMT_memory (VNULL, 1, sizeof (struct GRD_HEADER), arg);
-	
+
 	return (G);
 }
 
