@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: grdimage.c,v 1.55 2006/05/25 12:51:55 remko Exp $
+ *	$Id: grdimage.c,v 1.57 2006/10/29 01:55:42 remko Exp $
  *
  *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
@@ -141,7 +141,7 @@ int main (int argc, char **argv)
 						case 'F':
 						case 'f':
 							if (GMT_getrgb (&argv[i][3], Ctrl->G.f_rgb)) {
-								GMT_rgb_syntax ('G');
+								GMT_rgb_syntax ('G', " ");
 								error++;
 							}
 							else
@@ -150,7 +150,7 @@ int main (int argc, char **argv)
 						case 'B':
 						case 'b':
 							if (GMT_getrgb (&argv[i][3], Ctrl->G.b_rgb)) {
-								GMT_rgb_syntax ('G');
+								GMT_rgb_syntax ('G', " ");
 								error++;
 							}
 							else
@@ -158,7 +158,7 @@ int main (int argc, char **argv)
 							break;
 						default:	/* Same as -Gf */
 							if (GMT_getrgb (&argv[i][2], Ctrl->G.f_rgb)) {
-								GMT_rgb_syntax ('G');
+								GMT_rgb_syntax ('G', " ");
 								error++;
 							}
 							else
@@ -194,7 +194,7 @@ int main (int argc, char **argv)
 						Ctrl->T.outline = TRUE;
 						k++;
 						if (argv[i][k] && GMT_getpen (&argv[i][k], &Ctrl->T.pen)) {
-							GMT_pen_syntax ('T');
+							GMT_pen_syntax ('T', " ");
 							error++;
 						}
 					}
@@ -233,8 +233,7 @@ int main (int argc, char **argv)
 		fprintf(stderr, "\t-E sets dpi for the projected grid which must be constructed\n");
 		fprintf(stderr, "\t   if -Jx or -Jm is not selected [Default gives same size as input grid]\n");
 		fprintf(stderr, "\t   Give i to do the interpolation in PostScript at device resolution.\n");
-		fprintf (stderr,"\t-G sets transparency color for images that\n");
-		fprintf (stderr,"\t   otherwise would result in 1-bit images\n");
+		GMT_rgb_syntax ('G', "sets transparency color for images that otherwise would result in 1-bit images\n");
 		fprintf (stderr,"\t-I use illumination.  Append name of intensity grd file\n");
 		GMT_explain_option ('K');
 		fprintf (stderr, "\t-M force monochrome image\n");
@@ -243,9 +242,7 @@ int main (int argc, char **argv)
 		fprintf(stderr, "\t-Q use PS Level 3 colormasking for nodes with z = NaN.\n");
 		GMT_explain_option ('R');
 		fprintf(stderr, "\t-S sets the search radius in projected units [Default avoids aliasing]\n");
-		fprintf(stderr, "\t-T will image the data without interpolation by painting polygonal tiles\n");
-		fprintf(stderr, "\t   Append s to skip tiles for nodes with z = NaN [Default paints all tiles]\n");
-		fprintf(stderr, "\t   Append o[<pen>] to draw tile outline [Default uses no outline]\n");
+		GMT_pen_syntax ('T', "will image the data without interpolation by painting polygonal tiles\n\t   Append s to skip tiles for nodes with z = NaN [Default paints all tiles]\n\t   Append o[<pen>] to draw tile outline [Default uses no outline]");
 		GMT_explain_option ('U');
 		GMT_explain_option ('V');
 		GMT_explain_option ('X');
@@ -455,7 +452,7 @@ int main (int argc, char **argv)
 			grd_y = GMT_j_to_y (j, g_head[0].y_min, g_head[0].y_max, g_head[0].y_inc, g_head[0].xy_off, g_head[0].ny);
 			y_bot = grd_y - dy2;
 			y_top = grd_y + dy2;
-			if (project_info.degree[1]) {
+			if (GMT_io.in_col_type[1] == GMT_IS_LAT) {
 				if (y_bot < -90.0) y_bot = -90.0;
 				if (y_top > +90.0) y_top = +90.0;
 			}
